| Type: | Package |
| Title: | Continuous and Dichotomized Index Predictors Based on Distribution Quantiles |
| Version: | 0.2.0 |
| Date: | 2026-07-16 |
| Description: | The author has retired from academic research. Accordingly, this package should not be considered a validated tool for use in peer-reviewed publications or as the basis for grant applications. Backward compatibility with user-code published in <doi:10.1186/s12859-023-05408-8> and <doi:10.1016/j.labinv.2023.100158> is not maintained in versions >= 0.4.0 (June 2026) of this package. The authors of those publications are the appropriate contacts for reproducibility inquiries. |
| Encoding: | UTF-8 |
| License: | GPL-2 |
| Depends: | R (≥ 4.6), |
| Language: | en-US |
| Imports: | cli |
| Suggests: | boot |
| Config/roxygen2/version: | 8.0.0 |
| NeedsCompilation: | no |
| Packaged: | 2026-07-17 01:32:17 UTC; tingtingzhan |
| Author: | Tingting Zhan |
| Maintainer: | Tingting Zhan <tingtingzhan@gmail.com> |
| Repository: | CRAN |
| Date/Publication: | 2026-07-17 06:40:20 UTC |
Qindex: Continuous and Dichotomized Index Predictors Based on Distribution Quantiles
Description
The author has retired from academic research. Accordingly, this package should not be considered a validated tool for use in peer-reviewed publications or as the basis for grant applications. Backward compatibility with user-code published in doi:10.1186/s12859-023-05408-8 and doi:10.1016/j.labinv.2023.100158 is not maintained in versions >= 0.4.0 (June 2026) of this package. The authors of those publications are the appropriate contacts for reproducibility inquiries.
Note
This R package author has retired from academic research.
Accordingly, this package should not be considered a validated tool for use in peer-reviewed publications or as the basis for grant applications.
Backward compatibility with user-code published in the following publications is not maintained in versions '>= 0.4.0' of this package. The authors of those publications are the appropriate contacts for reproducibility inquiries.
doi:10.1186/s12859-023-05408-8 doi:10.1016/j.labinv.2023.100158
Author(s)
Maintainer: Tingting Zhan tingtingzhan@gmail.com (ORCID)
Authors:
Tingting Zhan tingtingzhan@gmail.com (ORCID)
Bootstrap Indices
Description
Generate a series of bootstrap indices.
Usage
bootid(n, R)
Arguments
n |
positive integer scalar, sample size |
R |
positive integer scalar, number of bootstrap replicates |
Details
The function [bootid()] generates the same bootstrap indices as those generated from the default options of function boot (i.e., ‘sim = ’ordinary'' and 'm = 0').
Value
The function [bootid()] returns a length-R list of
positive integer vectors.
Each element is the length-n indices of each bootstrap sample.
See Also
The function [bootid()] is inspired by functions 'boot:::index.array' and 'boot:::ordinary.array'.
Examples
set.seed(1345); (bt1 = boot::boot(data = 1:10, statistic = function(data, ind) ind, R = 3L)[['t']])
set.seed(1345); (bt2 = do.call(rbind, bootid(10L, R = 3L)))
stopifnot(identical(bt1, bt2))