Package 'Qindex'

Title: Continuous and Dichotomized Index Predictors Based on Distribution Quantiles
Description: The author has retired from academic research. Accordingly, this package should not be considered a validated tool for use in peer-reviewed publications or as the basis for grant applications. Backward compatibility with user-code published in <doi:10.1186/s12859-023-05408-8> and <doi:10.1016/j.labinv.2023.100158> is not maintained in versions >= 0.4.0 (June 2026) of this package. The authors of those publications are the appropriate contacts for reproducibility inquiries.
Authors: Tingting Zhan [aut, cre] (ORCID: <https://orcid.org/0000-0001-9971-4844>)
Maintainer: Tingting Zhan <[email protected]>
License: GPL-2
Version: 0.2.0
Built: 2026-07-17 09:36:29 UTC
Source: https://github.com/cran/Qindex

Help Index


Qindex: Continuous and Dichotomized Index Predictors Based on Distribution Quantiles

Description

The author has retired from academic research. Accordingly, this package should not be considered a validated tool for use in peer-reviewed publications or as the basis for grant applications. Backward compatibility with user-code published in doi:10.1186/s12859-023-05408-8 and doi:10.1016/j.labinv.2023.100158 is not maintained in versions >= 0.4.0 (June 2026) of this package. The authors of those publications are the appropriate contacts for reproducibility inquiries.

Note

This R package author has retired from academic research.

Accordingly, this package should not be considered a validated tool for use in peer-reviewed publications or as the basis for grant applications.

Backward compatibility with user-code published in the following publications is not maintained in versions '>= 0.4.0' of this package. The authors of those publications are the appropriate contacts for reproducibility inquiries.

doi:10.1186/s12859-023-05408-8 doi:10.1016/j.labinv.2023.100158

Author(s)

Maintainer: Tingting Zhan [email protected] (ORCID)

Authors: